/*
 *  /MathJax/localization/kn/FontWarnings.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("kn","FontWarnings",{version:"2.7.5",isLoaded:true,strings:{webFont:"\u0CAE\u0CBE\u0CA4\u0CCD \u0C9D\u0C95\u0CCD\u0CB7\u0CCD \u0C88 \u0CAA\u0CC1\u0C9F\u0CA6\u0CB2\u0CCD\u0CB2\u0CBF \u0C97\u0CA3\u0CBF\u0CA4 \u0CAA\u0CCD\u0CB0\u0CA6\u0CB0\u0CCD\u0CB6\u0CBF\u0CB8\u0CB2\u0CC1 \u0CB5\u0CC6\u0CAC\u0CCD \u0C86\u0CA7\u0CBE\u0CB0\u0CBF\u0CA4 \u0CAB\u0CBE\u0C82\u0C9F\u0CCD \u0CAC\u0CB3\u0CB8\u0CBF \u0C87\u0CA6\u0CC6. \u0C88 \u0CA1\u0CCC\u0CA8\u0CCD\u0CB2\u0CCB\u0CA1\u0CCD \u0CB8\u0CAE\u0CAF \u0CA4\u0CC6\u0C97\u0CC6\u0CA6\u0CC1\u0C95\u0CCA\u0CB3\u0CCD\u0CB3\u0CAC\u0CB9\u0CC1\u0CA6\u0CC1, \u0C86\u0CA6\u0CCD\u0CA6\u0CB0\u0CBF\u0C82\u0CA6 \u0CA8\u0CC0\u0CB5\u0CC1 \u0CA8\u0CBF\u0CAE\u0CCD\u0CAE \u0C97\u0CA3\u0C95\u0CA6 \u0CAB\u0CBE\u0C82\u0C9F\u0CCD \u0CAB\u0CCB\u0CB2\u0CCD\u0CA1\u0CB0\u0CCD\u0CA8\u0CB2\u0CCD\u0CB2\u0CBF \u0CA8\u0CC7\u0CB0\u0CB5\u0CBE\u0C97\u0CBF \u0C97\u0CA3\u0CBF\u0CA4 \u0CAB\u0CBE\u0C82\u0C9F\u0CCD\u0C97\u0CB3\u0CC1 \u0C87\u0CA8\u0CCD\u0CB8\u0CCD\u0C9F\u0CBE\u0CB2\u0CCD \u0CB5\u0CC7\u0CB3\u0CC6 \u0CAA\u0CC1\u0C9F \u0CB5\u0CC7\u0C97\u0CB5\u0CBE\u0C97\u0CBF \u0CA8\u0CBF\u0CB0\u0CC2\u0CAA\u0CBF\u0CB8\u0CB2\u0CC1 \u0C8E\u0C82\u0CA6\u0CC1.",noFonts:"\u0CAE\u0CBE\u0CA4\u0CCD \u0C9C\u0C95\u0CCD\u0CB7\u0CCD       \u0C85\u0CA6\u0CB0 \u0C97\u0CA3\u0CBF\u0CA4 \u0CAA\u0CCD\u0CB0\u0CA6\u0CB0\u0CCD\u0CB6\u0CBF\u0CB8\u0CB2\u0CC1 \u0CAC\u0CB3\u0CB8\u0CB2\u0CC1 \u0C92\u0C82\u0CA6\u0CC1 \u0CAB\u0CBE\u0C82\u0C9F\u0CCD \u0CAA\u0CA4\u0CCD\u0CA4\u0CC6 \u0CAE\u0CBE\u0CA1\u0CB2\u0CC1 \u0CB8\u0CBE\u0CA7\u0CCD\u0CAF\u0CB5\u0CBE\u0C97\u0CB2\u0CBF\u0CB2\u0CCD\u0CB2, \u0CAE\u0CA4\u0CCD\u0CA4\u0CC1 \u0C9A\u0CBF\u0CA4\u0CCD\u0CB0 \u0CAB\u0CBE\u0C82\u0C9F\u0CCD\u0C97\u0CB3\u0CC1 \u0CB2\u0CAD\u0CCD\u0CAF\u0CB5\u0CBF\u0CB2\u0CCD\u0CB2, \u0C86\u0CA6\u0CCD\u0CA6\u0CB0\u0CBF\u0C82\u0CA6 \u0CA8\u0CBF\u0CAE\u0CCD\u0CAE \u0CAC\u0CCD\u0CB0\u0CCC\u0CB8\u0CB0\u0CCD \u0C85\u0CB5\u0CC1\u0C97\u0CB3\u0CA8\u0CCD\u0CA8\u0CC1 \u0CAA\u0CCD\u0CB0\u0CA6\u0CB0\u0CCD\u0CB6\u0CBF\u0CB8\u0CB2\u0CC1 \u0CB8\u0CBE\u0CA7\u0CCD\u0CAF\u0CB5\u0CBE\u0C97\u0CC1\u0CA4\u0CCD\u0CA4\u0CA6\u0CC6 \u0C8E\u0C82\u0CA6\u0CC1 \u0CAD\u0CB0\u0CB5\u0CB8\u0CC6\u0CAF\u0CB2\u0CCD\u0CB2\u0CBF \u0CB8\u0CBE\u0CB0\u0CCD\u0CB5\u0CA4\u0CCD\u0CB0\u0CBF\u0C95 \u0CAF\u0CC1\u0CA8\u0CBF\u0C95\u0CCB\u0CA1\u0CCD \u0CAA\u0CBE\u0CA4\u0CCD\u0CB0\u0C97\u0CB3\u0CC1 \u0CB9\u0CBF\u0C82\u0CA6\u0CC6 \u0CAC\u0CC0\u0CB3\u0CC1\u0CB5 \u0C87\u0CA6\u0CC6. \u0C95\u0CC6\u0CB2\u0CB5\u0CC1 \u0CAA\u0CBE\u0CA4\u0CCD\u0CB0\u0C97\u0CB3\u0CC1 \u0CB8\u0CB0\u0CBF\u0CAF\u0CBE\u0C97\u0CBF, \u0C85\u0CA5\u0CB5\u0CBE \u0CAC\u0CB9\u0CC1\u0CB6\u0C83 \u0C8E\u0CB2\u0CCD\u0CB2\u0CBE \u0CA8\u0CB2\u0CCD\u0CB2\u0CBF \u0CA4\u0CCB\u0CB0\u0CBF\u0CB8\u0CC1\u0CA4\u0CCD\u0CA4\u0CB5\u0CC6 \u0C87\u0CB0\u0CAC\u0CB9\u0CC1\u0CA6\u0CC1.",webFonts:"\u0CAB\u0CBE\u0C82\u0C9F\u0CCD\u0C97\u0CB3\u0CC1 \u0CB5\u0CC6\u0CAC\u0CCD \u0CA1\u0CCC\u0CA8\u0CCD\u0CB2\u0CCB\u0CA1\u0CCD \u0CAE\u0CBE\u0CA1\u0CB2\u0CC1 \u0C85\u0CA4\u0CCD\u0CAF\u0C82\u0CA4 \u0C86\u0CA7\u0CC1\u0CA8\u0CBF\u0C95 \u0CAC\u0CCD\u0CB0\u0CCC\u0CB8\u0CB0\u0CCD\u0C97\u0CB3\u0CC1 \u0C85\u0CB5\u0C95\u0CBE\u0CB6. \u0CA8\u0CBF\u0CAE\u0CCD\u0CAE \u0CAC\u0CCD\u0CB0\u0CCC\u0CB8\u0CB0\u0CCD (\u0C85\u0CA5\u0CB5\u0CBE \u0CAC\u0CCD\u0CB0\u0CCC\u0CB8\u0CB0\u0CCD \u0CAC\u0CA6\u0CB2\u0CBE\u0CB5\u0CA3\u0CC6) \u0C87\u0CA4\u0CCD\u0CA4\u0CC0\u0C9A\u0CBF\u0CA8 \u0C86\u0CB5\u0CC3\u0CA4\u0CCD\u0CA4\u0CBF\u0C97\u0CC6 \u0C85\u0CAA\u0CCD\u0CA1\u0CC7\u0C9F\u0CCD \u0C88 \u0CAA\u0CC1\u0C9F\u0CA6\u0CB2\u0CCD\u0CB2\u0CBF \u0C97\u0CA3\u0CBF\u0CA4 \u0C97\u0CC1\u0CA3\u0CAE\u0C9F\u0CCD\u0C9F\u0CB5\u0CA8\u0CCD\u0CA8\u0CC1 \u0CB8\u0CC1\u0CA7\u0CBE\u0CB0\u0CBF\u0CB8\u0CB2\u0CC1 \u0CB8\u0CBE\u0CA7\u0CCD\u0CAF\u0CB5\u0CBF\u0CB2\u0CCD\u0CB2.",fonts:"\u0CAE\u0CBE\u0CA4\u0CCD \u0C9C\u0C95\u0CCD\u0CB7\u0CCD \u0C92\u0C82\u0CA6\u0CCB [\u0CB7\u0CCD\u0CA4\u0CBF\u0C95\u0CCD\u0CB7\u0CCD \u0CAB\u0CBE\u0C82\u0C9F\u0CCD\u0C97\u0CB3\u0CC1](%1) \u0C85\u0CA5\u0CB5 [\u0CAE\u0CBE\u0CA4\u0CCD \u0C9C\u0C95\u0CCD\u0CB7\u0CCD \u0CA4\u0CC6\u0C95\u0CCD\u0CB7\u0CCD \u0CAB\u0CBE\u0C82\u0C9F\u0CCD\u0C97\u0CB3\u0CC1](%2) \u0C85\u0CA8\u0CCD\u0CA8\u0CC1 \u0C89\u0CAA\u0CAF\u0CCB\u0C97 \u0CAE\u0CBE\u0CA6\u0CAC\u0CB9\u0CC1\u0CA6\u0CC1. \u0CA8\u0CBF\u0CAE\u0CCD\u0CAE \u0CAE\u0CBE\u0CA4 \u0C9C\u0C95\u0CCD\u0CB7\u0CCD \u0C85\u0CA8\u0CC1\u0CAD\u0CB5 \u0CB5\u0CA8\u0CCD\u0CA8\u0CC1 \u0CB5\u0CB3\u0CCD\u0CB2\u0CA6\u0CC1 \u0CAE\u0CBE\u0CA1\u0CB2\u0CBF\u0C95\u0CCD\u0C95\u0CC6 \u0C87\u0CA6\u0CB0\u0CB2\u0CCD\u0CB2\u0CBF \u0CAF\u0CBE\u0CB5\u0CA6\u0CBE\u0CA6\u0CB0\u0CC1 \u0C92\u0C82\u0CA6\u0CA8\u0CCD\u0CA8 \u0CA1\u0CCC\u0CA8\u0CCD\u0CB2\u0CCB\u0CA1\u0CCD \u0CAE\u0CBE\u0CA1\u0CBF \u0C87\u0CA8\u0CCD\u0CB8\u0CCD\u0C9F\u0CBE\u0CB2\u0CCD \u0CAE\u0CBE\u0CA6\u0CBF\u0C95\u0CCA\u0CB2\u0CCD\u0CB2\u0CBF.",STIXPage:"\u0C88 \u0CAA\u0CC1\u0C9F  [\u0CB8\u0CCD\u0CA4\u0CBF\u0C95\u0CCD\u0CB7\u0CCD \u0CAB\u0CBE\u0C82\u0C9F\u0CCD \u0C97\u0CB3\u0CCD\u0CB3\u0CA8\u0CCD\u0CA8\u0CC1 ](%1) \u0C89\u0CAA\u0CAF\u0CCB\u0C97 \u0CAE\u0CBE\u0CA1\u0CB2\u0CBF\u0C95\u0CCD\u0C95\u0CC6 \u0CB5\u0CBF\u0CA8\u0CCD\u0CAF\u0CBE\u0CB8 \u0C86\u0C97\u0CBF\u0CA6\u0CC6. \u0CA8\u0CBF\u0CAE\u0CCD\u0CAE \u0CAE\u0CBE\u0CA4\u0CCD \u0C9C\u0C95\u0CCD\u0CB7\u0CCD \u0C85\u0CA8\u0CC1\u0CAD\u0CB5 \u0CB5\u0CA8\u0CCD\u0CA8\u0CC1 \u0CB8\u0CC1\u0CA7\u0CBE\u0CB0\u0CBF\u0CB8\u0CB2\u0CBF\u0C95\u0CCD\u0C95\u0CC6 \u0C88 \u0CAB\u0CBE\u0C82\u0C9F\u0CCD \u0C97\u0CB3\u0CA8\u0CCD\u0CA8 \u0CA1\u0CCC\u0CA8\u0CCD\u0CB2\u0CCB\u0CA1\u0CCD \u0CAE\u0CBE\u0CA1\u0CBF \u0C87\u0CA8\u0CCD\u0CB8\u0CCD\u0C9F\u0CBE\u0CB2\u0CCD \u0CAE\u0CBE\u0CA1\u0CBF.",TeXPage:"\u0C88 \u0CAA\u0CC1\u0C9F  [\u0CAE\u0CBE\u0CA4\u0CCD \u0C9C\u0C95\u0CCD\u0CB7\u0CCD \u0CA4\u0CC6\u0C95\u0CCD\u0CB7\u0CCD   \u0CAB\u0CBE\u0C82\u0C9F\u0CCD \u0C97\u0CB3\u0CCD\u0CB3\u0CA8\u0CCD\u0CA8\u0CC1 ](%1) \u0C89\u0CAA\u0CAF\u0CCB\u0C97 \u0CAE\u0CBE\u0CA1\u0CB2\u0CBF\u0C95\u0CCD\u0C95\u0CC6 \u0CB5\u0CBF\u0CA8\u0CCD\u0CAF\u0CBE\u0CB8 \u0C86\u0C97\u0CBF\u0CA6\u0CC6. \u0CA8\u0CBF\u0CAE\u0CCD\u0CAE \u0CAE\u0CBE\u0CA4\u0CCD \u0C9C\u0C95\u0CCD\u0CB7\u0CCD \u0C85\u0CA8\u0CC1\u0CAD\u0CB5 \u0CB5\u0CA8\u0CCD\u0CA8\u0CC1 \u0CB8\u0CC1\u0CA7\u0CBE\u0CB0\u0CBF\u0CB8\u0CB2\u0CBF\u0C95\u0CCD\u0C95\u0CC6 \u0C88 \u0CAB\u0CBE\u0C82\u0C9F\u0CCD \u0C97\u0CB3\u0CA8\u0CCD\u0CA8 \u0CA1\u0CCC\u0CA8\u0CCD\u0CB2\u0CCB\u0CA1\u0CCD \u0CAE\u0CBE\u0CA1\u0CBF \u0C87\u0CA8\u0CCD\u0CB8\u0CCD\u0C9F\u0CBE\u0CB2\u0CCD \u0CAE\u0CBE\u0CA1\u0CBF.",imageFonts:"\u0CAE\u0CBE\u0CA4\u0CCD \u0C9D\u0C95\u0CCD\u0CB7\u0CCD \u0CA4\u0CA8\u0CCD\u0CA8 \u0C9A\u0CBF\u0CA4\u0CCD\u0CB0 \u0CAB\u0CBE\u0C82\u0C9F\u0CCD\u200C\u0C97\u0CB3\u0CA8\u0CCD\u0CA8\u0CC1 \u0CB8\u0CCD\u0CA5\u0CB3\u0CC0\u0CAF \u0C85\u0CA5\u0CB5\u0CBE \u0CB5\u0CC6\u0CAC\u0CCD-\u0C86\u0CA7\u0CBE\u0CB0\u0CBF\u0CA4 \u0CAB\u0CBE\u0C82\u200C\u0C9F\u0CCD\u200C\u0C97\u0CB3 \u0CAC\u0CA6\u0CB2\u0CBF\u0C97\u0CC6 \u0CAC\u0CB3\u0CB8\u0CC1\u0CA4\u0CCD\u0CA4\u0CA6\u0CC6. \u0C88 \u0CB8\u0CBE\u0CAE\u0CBE\u0CA8\u0CCD\u0CAF\u0C95\u0CCD\u0C95\u0CBF\u0C82\u0CA4 \u0CA8\u0CBF\u0CA7\u0CBE\u0CA8\u0CB5\u0CBE\u0C97\u0CBF \u0CAA\u0CCD\u0CB0\u0CA6\u0CB0\u0CCD\u0CB6\u0CBF\u0CA4\u0CB5\u0CBE\u0C97\u0CAC\u0CB9\u0CC1\u0CA6\u0CC1, \u0CAE\u0CA4\u0CCD\u0CA4\u0CC1 \u0C97\u0CA3\u0CBF\u0CA4 \u0CAA\u0CC2\u0CB0\u0CCD\u0CA3 \u0CB0\u0CC6\u0CB8\u0CB2\u0CCD\u0CAF\u0CC2\u0CB7\u0CA8\u0CCD\u200C\u0CA8\u0CB2\u0CCD\u0CB2\u0CBF \u0CA8\u0CBF\u0CAE\u0CCD\u0CAE \u0CAA\u0CCD\u0CB0\u0CBF\u0C82\u0C9F\u0CB0\u0CCD \u0CAE\u0CC2\u0CB2\u0C95 \u0CAE\u0CC1\u0CA6\u0CCD\u0CB0\u0CBF\u0CA4\u0CB5\u0CBE\u0C97\u0CA6\u0CBF\u0CB0\u0CAC\u0CB9\u0CC1\u0CA6\u0CC1."}});MathJax.Ajax.loadComplete("[MathJax]/localization/kn/FontWarnings.js");
