[{"locale":"es"},{"key":"mm","names":["mm"],"mappings":{"default":{"default":"milímetro"}},"category":"Length"},{"key":"cm","names":["cm"],"mappings":{"default":{"default":"centímetro"}},"category":"Length"},{"key":"m","names":["m"],"mappings":{"default":{"default":"metro"}},"category":"Length"},{"key":"km","names":["km"],"mappings":{"default":{"default":"kilómetro"}},"category":"Length"},{"key":"ft","names":["ft","ft."],"mappings":{"default":{"default":"pies"}},"category":"Length"},{"key":"in","names":["in","in."],"mappings":{"default":{"default":"pulgada"}},"category":"Length"},{"key":"mi","names":["mi","mi."],"mappings":{"default":{"default":"milla"}},"category":"Length"},{"key":"yd","names":["yd","yd."],"mappings":{"default":{"default":"yarda"}},"category":"Length"},{"key":"n.m.","names":["n.m."],"mappings":{"default":{"default":"millas náuticas"}}}]
